==> hoteldruid-mod-sv_2.1.2-1.tar.gz: sv/interconnessioni.php <==
<?php

switch ($messaggio) {

case "Aggiornamento eseguito con successo":  	$messaggio = "Framg&aring;ngsrikt uppdaterad"; break;
case "Non si è potuto portare a termine l'<div style=\"display: inline; color: red;\">aggiornamento</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Uppdatering</div> misslyckad"; break;
case "OK":  					$messaggio = "OK"; break;
case "<div style=\"display: inline; color: red;\"><b>ATTENZIONE</b></div>: premendo su <b>\"<i>Continua</i>\"</b> tutti i dati del <i>database attuale</i> verranno <b>cancellati</b>":	$messaggio = "<div style=\"display: inline; color: red;\"><b>VARNING</b></div>: om du klickar p&aring; <b>\"<i>Forts&auml;tt</i>\"</b> kommer alla data fr&aring;n <i>nuvarande databas</i> att <b>tas bort</b>"; break;
case "Continua":  				$messaggio = "Forts&auml;tt"; break;
case "Subordinazione creata":  			$messaggio = "Underordning skapad"; break;
case "Impossibile effettuare il collegamento, controllare i dati immessi":	$messaggio = "Koppling avb&ouml;jd, kontrollera infogade data"; break;
case "Subordinazione cancellata":  		$messaggio = "Underordning borttagen"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Interconnessioni con sorgenti esterne di dati":	$messaggio = "Samk&ouml;rning med externa datak&auml;llor"; break;
case "Cancella":  				$messaggio = "Ta bort"; break;
case "la subordinazione":  			$messaggio = "underordning"; break;
case "Con la subordinazione non si potranno inserire nuovi dati o apportare modifiche, ma solo importare i dati dall'installazione principale":	$messaggio = "Med underordning kommer du inte kunna infoga nya data eller till&auml;mpa &auml;ndringar, utan bara importera data fr&aring;n master-installationen"; break;
case "Password":  				$messaggio = "L&ouml;senord"; break;
case "Commento da aggiungere al titolo di questa installazione":	$messaggio = "Komment som ska l&auml;ggas till rubriken f&ouml;r den h&auml;r installationen"; break;
case "Crea la subordinazione":  		$messaggio = "Skapa underordning"; break;
case "Usa compressione":  			$messaggio = "Anv&auml;nd kompression"; break;
case "Utente per l'aggiornamento remoto delle interconnessioni":	$messaggio = "Anv&auml;ndare f&ouml;r att fj&auml;rran uppdatera samk&ouml;rning"; break;
case "Utente per l'aggiornamento remoto modificato":	$messaggio = "Anv&auml;ndare f&ouml;r fj&auml;rran uppdatering &auml;ndrad"; break;
case "Modifica":  				$messaggio = "&Auml;ndra"; break;
case "Subordinazione ad un'altra installazione di hoteldruid":	$messaggio = "Subordination to another installation of hoteldruid"; break;
case "Subordina questa installazione di hoteldruid a quella che si trova all'indirizzo":	$messaggio = "Subordinate this installation of hoteldruid to the one that is at"; break;
case "Aggiornamento codice sorgente eseguito con successo":  	$messaggio = "Source code updated successfully"; break;
case "amministratore o utente con i privilegi per creare backup":	$messaggio = "administrator or user with privileges to create backups"; break;
case "nome utente":  				$messaggio = "username"; break;
case "Versione locale diversa da quella remota":	$messaggio = "Local version is different from the remote one"; break;
case "Non si è potuto scaricare il backup remoto":	$messaggio = "It was not possible to download the backup"; break;
case "Non si è potuto stabilire la connessione":	$messaggio = "It was not possible to establish the connection"; break;
case "Non ho i permassi di scrittura sulla cartella dati":	$messaggio = "I don't have write premissions on dati folder"; break;
case "Prova a mantenere i dati degli anni non presenti nell'installazione remota":	$messaggio = "Try to retain data of years not present in remote installation"; break;
case "nella pagina delle interconnessioni":  	$messaggio = "in interconnections page"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-sv_2.2.3-1.tar.gz: sv/interconnessioni.php <==
<?php

switch ($messaggio) {

case "Aggiornamento eseguito con successo":  	$messaggio = "Framg&aring;ngsrikt uppdaterad"; break;
case "Non si è potuto portare a termine l'<div style=\"display: inline; color: red;\">aggiornamento</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Uppdatering</div> misslyckad"; break;
case "OK":  					$messaggio = "OK"; break;
case "<div style=\"display: inline; color: red;\"><b>ATTENZIONE</b></div>: premendo su <b>\"<i>Continua</i>\"</b> tutti i dati del <i>database attuale</i> verranno <b>cancellati</b>":	$messaggio = "<div style=\"display: inline; color: red;\"><b>VARNING</b></div>: om du klickar p&aring; <b>\"<i>Forts&auml;tt</i>\"</b> kommer alla data fr&aring;n <i>nuvarande databas</i> att <b>tas bort</b>"; break;
case "Continua":  				$messaggio = "Forts&auml;tt"; break;
case "Subordinazione creata":  			$messaggio = "Underordning skapad"; break;
case "Impossibile effettuare il collegamento, controllare i dati immessi":	$messaggio = "Koppling avb&ouml;jd, kontrollera infogade data"; break;
case "Subordinazione cancellata":  		$messaggio = "Underordning borttagen"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Interconnessioni con sorgenti esterne di dati":	$messaggio = "Samk&ouml;rning med externa datak&auml;llor"; break;
case "Cancella":  				$messaggio = "Ta bort"; break;
case "la subordinazione":  			$messaggio = "underordning"; break;
case "Con la subordinazione non si potranno inserire nuovi dati o apportare modifiche, ma solo importare i dati dall'installazione principale":	$messaggio = "Med underordning kommer du inte kunna infoga nya data eller till&auml;mpa &auml;ndringar, utan bara importera data fr&aring;n master-installationen"; break;
case "Password":  				$messaggio = "L&ouml;senord"; break;
case "Commento da aggiungere al titolo di questa installazione":	$messaggio = "Komment som ska l&auml;ggas till rubriken f&ouml;r den h&auml;r installationen"; break;
case "Crea la subordinazione":  		$messaggio = "Skapa underordning"; break;
case "Usa compressione":  			$messaggio = "Anv&auml;nd kompression"; break;
case "Utente per l'aggiornamento remoto delle interconnessioni":	$messaggio = "Anv&auml;ndare f&ouml;r att fj&auml;rran uppdatera samk&ouml;rning"; break;
case "Utente per l'aggiornamento remoto modificato":	$messaggio = "Anv&auml;ndare f&ouml;r fj&auml;rran uppdatering &auml;ndrad"; break;
case "Modifica":  				$messaggio = "&Auml;ndra"; break;
case "Subordinazione ad un'altra installazione di hoteldruid":	$messaggio = "Subordination to another installation of hoteldruid"; break;
case "Subordina questa installazione di hoteldruid a quella che si trova all'indirizzo":	$messaggio = "Subordinate this installation of hoteldruid to the one that is at"; break;
case "Aggiornamento codice sorgente eseguito con successo":  	$messaggio = "Source code updated successfully"; break;
case "amministratore o utente con i privilegi per creare backup":	$messaggio = "administrator or user with privileges to create backups"; break;
case "nome utente":  				$messaggio = "username"; break;
case "Versione locale diversa da quella remota":	$messaggio = "Local version is different from the remote one"; break;
case "Non si è potuto scaricare il backup remoto":	$messaggio = "It was not possible to download the backup"; break;
case "Non si è potuto stabilire la connessione":	$messaggio = "It was not possible to establish the connection"; break;
case "Non ho i permassi di scrittura sulla cartella dati":	$messaggio = "I don't have write premissions on dati folder"; break;
case "Prova a mantenere i dati degli anni non presenti nell'installazione remota":	$messaggio = "Try to retain data of years not present in remote installation"; break;
case "nella pagina delle interconnessioni":  	$messaggio = "in interconnections page"; break;
case "Modifica la regola di assegnazione":  	$messaggio = "Modify the assignment rule"; break;
case "La prenotazione cancellata non era presente nel database":	$messaggio = "The deleted reservation was not present in the database"; break;
case "gruppo":  				$messaggio = "group"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "carta di credito non salvata":  		$messaggio = "credit card not saved"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
